@@ -12,7 +12,7 @@ class ReceiptResource:
     """
     session: EtsySession
     
-    def get_receipts(self, shop_id: int, limit=25, offset=0, type: ReceiptType = ReceiptType.UNSHIPPED) -> Response[Receipt]:
+    def get_receipts(self, shop_id: int, limit=25, offset=0, type: ReceiptType = ReceiptType.UNSHIPPED, **kwargs) -> Response[Receipt]:
         """
         Get Shop Receipts By Shop ID And Receipt Type
 
@@ -31,6 +31,7 @@ class ReceiptResource:
         
         params = {"limit": limit, "offset": offset}
         params.update(type)
+        params.update(kwargs)
         json = self.session.request(endpoint=endpoint, params=params)
         
         return Response[Receipt](**json)
